@@ -1,9 +1,13 @@
 #ifndef COLUMBUSCONTROLLER_H
 #define COLUMBUSCONTROLLER_H
 
+#include "config.h"
+
 #include <rx/ConfigManager.h>
 
 #include "ColumbusModel.h"
+#include "ColumbusWaypointModel.h"
+
 #include "ColumbusPluginManager.h"
 
 #include "logging/LoggingManager.h"
@@ -26,12 +30,13 @@ public:
     explicit ColumbusController  (QObject *parent = 0);
             ~ColumbusController  ();
 
-    bool             initialize ();
+    bool                    initialize  ();
 
-    ConfigManager*   config     () const;
-    PluginManager*   plugins    () const;
-    LoggingManager*  logger     () const;
-    ColumbusModel*   model      () const;
+    ConfigManager*          config      () const;
+    PluginManager*          plugins     () const;
+    LoggingManager*         logger      () const;
+    ColumbusModel*          model       () const;
+    ColumbusWaypointModel*  waypoints   () const;
 
 signals:
     void positionUpdated            (const QGeoPositionInfo &position);
@@ -45,7 +50,7 @@ protected slots:
     void onPositionTimeout          ();
 
 protected:
-    void setupConfig                ();
+    void setupConfig();
 
 private:
     ColumbusControllerPrivate *d;
